@@ -1,9 +1,9 @@
-VERSION = (0, 2, 8)
+VERSION = (0, 2, 9)
 __version__ = '.'.join(map(str, VERSION))
 __author__ = "Derek Gulbranson"
 __author_email__ = 'derek73@gmail.com'
 __license__ = "LGPL"
-__url__ = "http://code.google.com/p/python-nameparser"
+__url__ = "https://github.com/derek73/python-nameparser"
 
 import sys
 if sys.version < '3':
